==> huaweicloudsdkmeeting-3.0.5b0-py3-none-any.whl: huaweicloudsdkmeeting/v1/model/delete_corp_request.py <==
# coding: utf-8

import pprint
import re

import six


class DeleteCorpRequest(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'x_request_id': 'str',
        'accept_language': 'str',
        'id': 'str',
        'force_delete': 'bool'
    }

    attribute_map = {
        'x_request_id': 'X-Request-Id',
        'accept_language': 'Accept-Language',
        'id': 'id',
        'force_delete': 'forceDelete'
    }

    def __init__(self, x_request_id=None, accept_language=None, id=None, force_delete=False):  # noqa: E501
        """DeleteCorpRequest - a model defined in huaweicloud sdk"""

        self._x_request_id = None
        self._accept_language = None
        self._id = None
        self._force_delete = None
        self.discriminator = None

        if x_request_id is not None:
            self.x_request_id = x_request_id
        if accept_language is not None:
            self.accept_language = accept_language
        self.id = id
        if force_delete is not None:
            self.force_delete = force_delete

    @property
    def x_request_id(self):
        """Gets the x_request_id of this DeleteCorpRequest.


        :return: The x_request_id of this DeleteCorpRequest.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        """Sets the x_request_id of this DeleteCorpRequest.


        :param x_request_id: The x_request_id of this DeleteCorpRequest.
        :type: str
        """
        self._x_request_id = x_request_id

    @property
    def accept_language(self):
        """Gets the accept_language of this DeleteCorpRequest.


        :return: The accept_language of this DeleteCorpRequest.
        :rtype: str
        """
        return self._accept_language

    @accept_language.setter
    def accept_language(self, accept_language):
        """Sets the accept_language of this DeleteCorpRequest.


        :param accept_language: The accept_language of this DeleteCorpRequest.
        :type: str
        """
        self._accept_language = accept_language

    @property
    def id(self):
        """Gets the id of this DeleteCorpRequest.


        :return: The id of this DeleteCorpRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeleteCorpRequest.


        :param id: The id of this DeleteCorpRequest.
        :type: str
        """
        self._id = id

    @property
    def force_delete(self):
        """Gets the force_delete of this DeleteCorpRequest.


        :return: The force_delete of this DeleteCorpRequest.
        :rtype: bool
        """
        return self._force_delete

    @force_delete.setter
    def force_delete(self, force_delete):
        """Sets the force_delete of this DeleteCorpRequest.


        :param force_delete: The force_delete of this DeleteCorpRequest.
        :type: bool
        """
        self._force_delete = force_delete

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteCorpRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmeeting-3.0.27b0-py3-none-any.whl: huaweicloudsdkmeeting/v1/model/delete_corp_request.py <==
# coding: utf-8

import pprint
import re

import six





class DeleteCorpRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'x_request_id': 'str',
        'accept_language': 'str',
        'id': 'str',
        'force_delete': 'bool'
    }

    attribute_map = {
        'x_request_id': 'X-Request-Id',
        'accept_language': 'Accept-Language',
        'id': 'id',
        'force_delete': 'forceDelete'
    }

    def __init__(self, x_request_id=None, accept_language=None, id=None, force_delete=False):
        """DeleteCorpRequest - a model defined in huaweicloud sdk"""
        
        

        self._x_request_id = None
        self._accept_language = None
        self._id = None
        self._force_delete = None
        self.discriminator = None

        if x_request_id is not None:
            self.x_request_id = x_request_id
        if accept_language is not None:
            self.accept_language = accept_language
        self.id = id
        if force_delete is not None:
            self.force_delete = force_delete

    @property
    def x_request_id(self):
        """Gets the x_request_id of this DeleteCorpRequest.


        :return: The x_request_id of this DeleteCorpRequest.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        """Sets the x_request_id of this DeleteCorpRequest.


        :param x_request_id: The x_request_id of this DeleteCorpRequest.
        :type: str
        """
        self._x_request_id = x_request_id

    @property
    def accept_language(self):
        """Gets the accept_language of this DeleteCorpRequest.


        :return: The accept_language of this DeleteCorpRequest.
        :rtype: str
        """
        return self._accept_language

    @accept_language.setter
    def accept_language(self, accept_language):
        """Sets the accept_language of this DeleteCorpRequest.


        :param accept_language: The accept_language of this DeleteCorpRequest.
        :type: str
        """
        self._accept_language = accept_language

    @property
    def id(self):
        """Gets the id of this DeleteCorpRequest.


        :return: The id of this DeleteCorpRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeleteCorpRequest.


        :param id: The id of this DeleteCorpRequest.
        :type: str
        """
        self._id = id

    @property
    def force_delete(self):
        """Gets the force_delete of this DeleteCorpRequest.


        :return: The force_delete of this DeleteCorpRequest.
        :rtype: bool
        """
        return self._force_delete

    @force_delete.setter
    def force_delete(self, force_delete):
        """Sets the force_delete of this DeleteCorpRequest.


        :param force_delete: The force_delete of this DeleteCorpRequest.
        :type: bool
        """
        self._force_delete = force_delete

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteCorpRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
